from paste import urlparser


def get_google_block(environ):
    base_url = 'http://ajax.googleapis.com/ajax/libs/dojo/1.3'
    return '''
<script type="text/javascript" src="%(base_url)s/dojo/dojo.xd.js"></script>
<link rel="stylesheet" href="%(base_url)s/dijit/themes/tundra/tundra.css"
      type="text/css" media="screen" title="dijit tundra css" charset="utf-8">
''' % {'base_url': base_url}


def make_app(global_conf={}):
    return urlparser.make_pkg_resources(global_conf,
                                        'ClueDojo',
                                        'cluedojo/static')



from setuptools import setup, find_packages

version = '1.4.1-1'

setup(name='ClueDojo',
      version=version,
      description='Simple wsgi app to serve up Dojo',
      long_description='',
      classifiers=[],
      keywords='',
      author='Rocky Burt',
      author_email='rocky@serverzen.com',
      url='https://dev.serverzen.com/svn/cluemapper/ClueDojo/',
      license='BSD',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'Paste',
          ],
      entry_points={
          'paste.app_factory': [
              'main=cluedojo.wsgiapp.make_app',
              ],
          },
      )
